import {
  Controller,
  Put,
  UseGuards,
  Get,
  Param,
  UsePipes,
  ValidationPipe,
  Body,
  Delete,
} from '@nestjs/common';
import { AuthGuard } from 'src/shared/auth.guard';
import { DrawService } from './draw.service';
import { MapDrawingDTO, DrawMapDTO } from './mapdrawing.dto';
import { Roles } from 'src/shared/roles.decorator';
import { User } from 'src/user/user.decorator';
import { FactionDTO } from 'src/game/game.dto';
import { FactionEntity } from 'src/game/faction.entity';
import { async } from 'rxjs/internal/scheduler/async';
import { Game_PersonEntity } from 'src/game/game.entity';
/*
      DrawController
  
      Functions either insert or return MapDrawing data,
      Insert functions require user to have proper role (either gm or commander) in the game to be able store the ddata: MapDrawingDTOata to database.
      Data return functions require atleast spectator role.
  */
@Controller('draw')
export class DrawController {
  constructor(private drawService: DrawService) {}

  @Put('mapdrawing/:id')
  @UsePipes(new ValidationPipe())
  @Roles('admin', 'factionleader')
  async draw(@Param('id') gameId, @Body() data) {
    return this.drawService.draw(gameId, data);
  }

  @Get('map/:id')
  @UseGuards(new AuthGuard())
  @UsePipes(new ValidationPipe())
  async drawMap(@Param('id') id, @Body() data) {
    return this.drawService.drawMap(id, data);
  }

  @Put('location')
  @UseGuards(new AuthGuard())
  @UsePipes(new ValidationPipe())
  async trackLocation() {}
}
